OC.L10N.register(
    "core",
    {
    "Please select a file." : "Wiel w.e.g. e Fichier aus.",
    "File is too big" : "De Fichier ass ze grouss",
    "Invalid file provided" : "Ongültege Fichier uginn",
    "No image or file provided" : "Kee Bild oder Fichier uginn",
    "Unknown filetype" : "Onbekannten Fichier Typ",
    "Invalid image" : "Ongültegt Bild",
    "An error occurred. Please contact your admin." : "Et ass e Feeler opgetrueden. W.e.g. kontaktéier däin Administrateur.",
    "No temporary profile picture available, try again" : "Et ass keen temporäert Profilbild verfügbar, versich et nach emol.",
    "%s password reset" : "%s Passwuert ass nei gesat",
    "Couldn't send reset email. Please contact your administrator." : "D'Email fir zeréck ze setzen konnt net geschéckt ginn. W.e.g. kontaktéier däin Administrateur.",
    "Preparing update" : "D'Aktualiséierung gëtt virbereet",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Reparatur Warnung:",
    "Repair error: " : "Reparéier de Feeler:",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Tabell gëtt gepréift %s",
    "Turned on maintenance mode" : "Maintenance Modus ass un",
    "Turned off maintenance mode" : "Maintenance Modus ass aus",
    "Maintenance mode is kept active" : "De Maintenance Modus gëtt aktiv gehalen",
    "Updating database schema" : "D'Schema vun der Datebank gëtt aktualiséiert",
    "Updated database" : "Datebank ass geupdate ginn",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Et gëtt gepréift ob d'Schema vun der Datebank aktualiséiert ka ginn (dëst kann ofhängeg vun der Gréisst vun der Datebank eng länger Zäit daueren)",
    "Checked database schema update" : "D'Aktualiséierung vum Schema vun der Datebank gouf gepréift",
    "Checking updates of apps" : "D'Aktualiséierung vun den Apps gëtt gepréift",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Et gëtt gepréift ob d'Schema vun der Datebank fir %s aktualiséiert ka ginn (dëst kann ofhängeg vun der Datebank eng länger Zäit daueren)",
    "Checked database schema update for apps" : "D'Aktualiséierung vum Schema vun der Datebank fir Applikatioune gouf gepréift",
    "Updated \"%s\" to %s" : "\"%s\" gouf op %s aktualiséiert",
    "Already up to date" : "Schonn um neiste Stand",
    "Sunday" : "Sonndeg",
    "Monday" : "Méindeg",
    "Tuesday" : "Dënschdeg",
    "Wednesday" : "Mëttwoch",
    "Thursday" : "Donneschdeg",
    "Friday" : "Freideg",
    "Saturday" : "Samschdeg",
    "Sun." : "So. ",
    "Mon." : "Méi.",
    "Tue." : "Dë.",
    "Wed." : "Më.",
    "Thu." : "Do.",
    "Fri." : "Fr.",
    "Sat." : "Sa.",
    "Su" : "SO",
    "Mo" : "ME",
    "Tu" : "DE",
    "We" : "ME",
    "Th" : "DO",
    "Fr" : "FR",
    "Sa" : "SA",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mäerz",
    "April" : "Abrëll",
    "May" : "Mee",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mäe.",
    "Apr." : "Abr.",
    "May." : "Mee",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Settings" : "Astellungen",
    "Problem loading page, reloading in 5 seconds" : "Et gouf e Problem beim Luede vun der Säit, a 5 Sekonnen gëtt nei gelueden",
    "Saving..." : "Speicheren...",
    "Dismiss" : "Verworf",
    "seconds ago" : "Sekonnen hier",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "De Link fir d'Passwuert zeréckzesetzen gouf un deng E-Mail-Adress geschéckt. Falls d'Mail net enger raisonnabeler Zäitspan ukënnt, kuck w.e.g. an dengem Spam-Dossier. Wann do och keng Mail ass, fro w.e.g. däin Administrateur.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Deng Fichiere si verschlësselt. Falls du de Recuperatiouns-Schlëssel net aktivéiert hues, gëtt et keng Méiglechkeet nees un deng Daten ze komme wann däi Passwuert bis zeréckgesat gouf. Falls du net sécher bass wat s de maache soll, kontaktéier w.e.g. däin Administrateur éiers de weiderfiers. Bass de sécher dass de weidermaache wëlls?",
    "I know what I'm doing" : "Ech weess wat ech maachen",
    "Password can not be changed. Please contact your administrator." : "D'Passwuert kann net geännert ginn. W.e.g. kontaktéier däin Administrateur.",
    "No" : "Nee",
    "Yes" : "Jo",
    "Choose" : "Auswielen",
    "Ok" : "OK",
    "Error loading message template: {error}" : "Feeler beim Luede vun der Noorichte Virlag: {Feeler}",
    "read-only" : "Nëmme liesen",
    "New Files" : "Nei Fichieren",
    "Already existing files" : "D'Fichieren existéiere schonn",
    "Which files do you want to keep?" : "Weieng Fichieren wëlls de gär behalen?",
    "If you select both versions, the copied file will have a number added to its name." : "Wann s de déi zwou Versiounen auswiels kritt de kopéierte Fichier eng Nummer bei den Numm derbäi gesat",
    "Cancel" : "Ofbriechen",
    "Continue" : "Weider",
    "(all selected)" : "(all ausgewielt)",
    "({count} selected)" : "({count} ausgewielt)",
    "Error loading file exists template" : "Feeler beim Luede vum Fichier existéiert eng Virlag",
    "Very weak password" : "Ganz schwaacht Passwuert",
    "Weak password" : "Schwaacht Passwuert",
    "So-so password" : "La-La Passwuert",
    "Good password" : "Gutt Passwuert",
    "Strong password" : "Staarkt Passwuert",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Däi Web Server ass net richteg agestallt fir d'Fichier Selektioun ze erlaben well den WebDAV Interface schéngt futti ze sinn.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Däi Web Server ass net richteg agestallt fir \"{url}\" ze léisen. Méi Informatiounen fënns de op eisem <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentatioun</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "D'Internet Verbindung fir dëse Server funktionéiert net. Dat bedeit dass e puer vun dëse Funktiounen wéi eng extern Späicherplaz ariichten, Notifikatiounen iwwer Aktualiséierungen oder d'Installéieren vu friemen Apps net funktionéiere wäert. Fichieren op Distanz erreechen an d'Schécke vu Notifikatioun Emailen kéinnten och net funktionéieren. Mir roden fir d'Internet Verbindung fir dëse Server hierzestellen wann s de all d'Funktioune wëlls hunn.",
    "Shared" : "Gedeelt",
    "Shared with {recipients}" : "Gedeelt mat {Empfänger}",
    "Error" : "Feeler",
    "Error while sharing" : "Feeler beim Deelen",
    "Error while unsharing" : "Feeler beim Annuléiere vum Deelen",
    "The public link will expire no later than {days} days after it is created" : "Den ëffentleche Link wäert net méi spéit wéi {Deeg} Deeg nodeems et erstallt gouf verfalen ",
    "Expiration" : "Leeft of",
    "Link" : "Link",
    "Edit" : "Änneren",
    "Remove" : "Läschen",
    "Name" : "Numm",
    "Password" : "Passwuert",
    "Share" : "Deelen",
    "Save" : "Späicheren",
    "Email link to person" : "Link enger Persoun mailen",
    "Send link via email" : "De Link iwwer E-Mail schécken",
    "Shared with you and the group {group} by {owner}" : "Gedeelt mat dir an der Grupp {group} vum {owner}",
    "Shared with you by {owner}" : "Gedeelt mat dir vum {owner}",
    "group" : "Grupp",
    "notify by email" : "via e-mail Bescheed ginn",
    "Unshare" : "Net méi deelen",
    "can share" : "kann deelen",
    "can edit" : "kann änneren",
    "create" : "erstellen",
    "change" : "änneren",
    "delete" : "läschen",
    "access control" : "Zougrëffskontroll",
    "Could not unshare" : "Konnt net ongedeelt ginn",
    "Share details could not be loaded for this item." : "D'Detailer vum Deelen konnten net geluede ginn fir dësen Artikel.",
    "No users or groups found for {search}" : "Keng Benotzer oder Gruppe fonnt fir {Sich}",
    "No users found for {search}" : "Keng Benotzer fonnt fir {Sich}",
    "An error occurred. Please try again" : "Et ass e Fehler opgetrueden. W.e.g. probéier nach emol",
    "User" : "Benotzer",
    "Group" : "Grupp",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Mat Leit vun aneren ownCloud deelen, déi d'Syntax username@example.com/owncloud benotzen",
    "Share with users…" : "Mat Benotzer deelen ...",
    "Share with users, groups or remote users…" : "Mat Benotzer, Gruppen oder Benotzer op Distanz deelen ...",
    "Share with users or groups…" : "Mat Benotzer oder Gruppen deelen...",
    "Share with users or remote users…" : "Mat Benotzer oder mat Benotzer op Distanz deelen ...",
    "Error removing share" : "Fehler beim Läschen vum Bäitrag",
    "restricted" : "Ageschränkt",
    "invisible" : "Onsiichtbar",
    "Delete" : "Läschen",
    "Rename" : "Ëmbenennen",
    "The object type is not specified." : "Den Typ vum Object ass net uginn.",
    "Enter new" : "Gëff nei an",
    "Add" : "Dobäisetzen",
    "Edit tags" : "Tags editéieren",
    "unknown text" : "Onbekannten Text",
    "Hello world!" : "Hallo Welt!",
    "sunny" : "Sonneg",
    "Hello {name}, the weather is {weather}" : "Hallo {Numm}, d'Wieder ass {Wieder}",
    "Hello {name}" : "Hallo {Numm}",
    "new" : "Nei",
    "_download %n file_::_download %n files_" : ["%n Fichier eroflueden","%n Fichieren eroflueden"],
    "Updating to {version}" : "Aktualiséieren op {Versioun}",
    "An error occurred." : "Et ass e Feeler opgetrueden",
    "Please reload the page." : "Lued w.e.g. d'Säit nei.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "D'Aktualiséierung war net erfollegräich. Fir méi Informatiounen  <a href=\"{url}\">Kuck eise Forum Bäitrag</a> deen dëst Thema behandelt.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "D'Aktualiséierung war net erfollegräich. Mell dëse Problem w.e.gl der<a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud-Community</a>.",
    "The update was successful. There were warnings." : "D'Aktualiséierung war erfollegräich. Et goufe Warnungen.",
    "The update was successful. Redirecting you to ownCloud now." : "D'Aktualiséierung war erfollegräich.  Du gëss elo bei d'ownCloud ëmgeleet.",
    "Searching other places" : "Op anere Plaaze sichen",
    "No search results in other folders" : "Keng Sich Resultater an aneren Dossieren",
    "Personal" : "Perséinlech",
    "Users" : "Benotzer",
    "Apps" : "Applikatiounen",
    "Admin" : "Admin",
    "Help" : "Hëllef",
    "Access forbidden" : "Zougrëff net erlaabt",
    "File not found" : "Fichier net fonnt",
    "The specified document has not been found on the server." : "Dat ausgewielt Dokument konnt net op dësem Server fonnt ginn.",
    "You can click here to return to %s." : "Du kanns hei klicken fir bei %s zeréck ze goen.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hallo,\n\nech wëll just Bescheed soen dass den/d' %s,  »%s« mat dir gedeelt huet.\nUkucken: %s\n",
    "Cheers!" : "Prost!",
    "Internal Server Error" : "Interne Server Feeler",
    "The server encountered an internal error and was unable to complete your request." : "De Server huet en interne Feeler festgestallt an konnt deng Ufro net ëmsetzen",
    "Technical details" : "Technesch Detailer",
    "Remote Address: %s" : "D'Adress op Distanz: %s",
    "Request ID: %s" : "ID ufroen: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Noriicht: %s",
    "File: %s" : "Fichier: %s",
    "Line: %s" : "Zeil: %s",
    "Trace" : "Spuren",
    "Imprint" : "Impressum",
    "Create an <strong>admin account</strong>" : "En <strong>Admin-Account</strong> uleeën",
    "Username" : "Benotzernumm",
    "Storage & database" : "Speicherplaz & Datebank",
    "Data folder" : "Daten-Dossier",
    "Configure the database" : "D'Datebank konfiguréieren",
    "Only %s is available." : "Nëmmen den %s ass verfügbar.",
    "Install and activate additional PHP modules to choose other database types." : "Installéier an aktivéier zousätzlech PHP Moduler fir aner Forme vun Datebanken auszewielen.",
    "For more details check out the documentation." : "Kuck an der Dokumentatioun fir méi Informatiounen.",
    "Database user" : "Datebank-Benotzer",
    "Database password" : "Datebank-Passwuert",
    "Database name" : "Datebank Numm",
    "Database tablespace" : "Tabelle-Plaz vun der Datebank",
    "Database host" : "Datebank-Server",
    "Performance warning" : "Leeschtungs Warnung",
    "SQLite will be used as database." : "SQLite wäert als Datebank benotzt ginn.",
    "For larger installations we recommend to choose a different database backend." : "Fir méi grouss Installatiounen recommandéiere mir fir en aneren Datebanken Backend ze benotzen.",
    "Finish setup" : "Installatioun ofschléissen",
    "Finishing …" : "Schléissen of ...",
    "Need help?" : "Brauchs de Hëllef?",
    "See the documentation" : "Kuck an der Dokumentatioun",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>ech wëll just Bescheed soen dass den/d' %s <strong>%s</strong> mat dir gedeelt huet.<br><a href=\"%s\">Ukucken!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Dës Applikatioun verlaangt JavaScript fir kënne korrekt auszeféieren. W.e.g {linkstart} schalt JavaScript an {linkend} a luet d'Säit nei.",
    "Menu" : "Menü",
    "Log out" : "Ofmellen",
    "Search" : "Sichen",
    "Server side authentication failed!" : "D'Autentifikatioun vun der Säit vum Server huet net geklappt!",
    "Please contact your administrator." : "W.e.g. kontaktéier däin Administrateur.",
    "An internal error occurred." : "Et ass en interne Feeler opgetrueden.",
    "Please try again or contact your administrator." : "W.e.g. versich et nach emol oder kontaktéier däin Administrateur.",
    "Login" : "Login",
    "Username or email" : "Benotzernumm oder Email",
    "Wrong password. Reset it?" : "Falscht Passwuert. Wëlls de et zeréck setzen?",
    "Wrong password." : "Falscht Passwuert.",
    "Stay logged in" : "Bleif ageloggt.",
    "Alternative Logins" : "Alternativ Umeldungen",
    "Use the following link to reset your password: {link}" : "Benotz folgende Link fir däi Passwuert zréckzesetzen: {link}",
    "New password" : "Neit Passwuert",
    "New Password" : "Neit Passwuert",
    "Reset password" : "Passwuert zréck setzen",
    "This ownCloud instance is currently in single user mode." : "Dës ownCloud Instanz ass am Moment am eenzel Benotzer Modus.",
    "This means only administrators can use the instance." : "Dëst bedeit dass just d'Administrateuren d'Instanz benotze kënnen.",
    "Thank you for your patience." : "Merci fir deng Gedold.",
    "Two-step verification" : "Verifikatioun mat zwee Schrëtt",
    "Cancel login" : "Login ofbriechen",
    "Please authenticate using the selected factor." : "W.e.g. authentifizéier dech andeems de den ausgewielten Facteur benotz.",
    "You are accessing the server from an untrusted domain." : "Du gräifs vun enger net vertrauensvoller Domän op dëse Server zou.",
    "App update required" : "App Aktualiséierung néideg",
    "%s will be updated to version %s" : "%s wäert aktualiséiert ginn op d'Versioun %s",
    "These apps will be updated:" : "D!es Apps wäerten aktualiséiert ginn:",
    "The theme %s has been disabled." : "D'Thema %s gouf ofgeschalt.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "W.e.g. géi sécher dass d'Datebank, de configuréierten Dossier an den Daten Dossier ofgeséchert sinn éiers de weider gees.",
    "Start update" : "Update starten",
    "Detailed logs" : "Detailléiert Loggs",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Fir Hëllef, kuck am <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Documentatioun</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Dës %s Instanz ass am Moment am Maintenance Modus, dat kënnt ee Moment brauche.",
    "This page will refresh itself when the %s instance is available again." : "Dës Säit luet nees automatesch wann d' %s Instanz nees disponibel ass."
},
"nplurals=2; plural=(n != 1);");
